@@ -19,17 +19,18 @@
 
 
 jQuery(function($) {
-	var KEY = {
-		ARROW_DOWN: 40,
-		ARROW_LEFT: 37,
-		ARROW_RIGHT: 39,
-		ARROW_UP: 38,
-		BACKSPACE: 8,
-		DELETE: 46,
-		ENTER: 13,
-		ESCAPE: 27,
-		TAB: 9
-	};
+	var ZBX_STYLE_CLASS = 'multiselect-control',
+		KEY = {
+			ARROW_DOWN: 40,
+			ARROW_LEFT: 37,
+			ARROW_RIGHT: 39,
+			ARROW_UP: 38,
+			BACKSPACE: 8,
+			DELETE: 46,
+			ENTER: 13,
+			ESCAPE: 27,
+			TAB: 9
+		};
 
 	/**
 	 * Multi select helper.
@@ -117,8 +118,8 @@ jQuery(function($) {
 		 */
 		addData: function(item) {
 			return this.each(function() {
-				var obj = $(this);
-				var ms = $(this).data('multiSelect');
+				var obj = $(this),
+					ms = $(this).data('multiSelect');
 
 				// clean input if selectedLimit == 1
 				if (ms.options.selectedLimit == 1) {
@@ -158,13 +159,13 @@ jQuery(function($) {
 		disable: function() {
 			return this.each(function() {
 				var $obj = $(this),
-					$wrapper = $obj.parent('.multiselect-wrapper'),
+					$wrapper = $obj.parent('.'+ZBX_STYLE_CLASS),
 					ms = $obj.data('multiSelect');
 
 				if (ms.options.disabled === false) {
 					$obj.attr('aria-disabled', true);
 					$('.multiselect-list', $obj).addClass('disabled');
-					$('.multiselect-button > button', $wrapper).attr('disabled', 'disabled');
+					$('.multiselect-button > button', $wrapper).prop('disabled', true);
 					$('input[type=text]', $wrapper).remove();
 					cleanAvailable($obj, ms.values);
 					$('.available', $wrapper).remove();
@@ -182,14 +183,14 @@ jQuery(function($) {
 		enable: function() {
 			return this.each(function() {
 				var $obj = $(this),
-					$wrapper = $obj.parent('.multiselect-wrapper'),
+					$wrapper = $obj.parent('.'+ZBX_STYLE_CLASS),
 					ms = $(this).data('multiSelect');
 
 				if (ms.options.disabled === true) {
 					var $input = makeMultiSelectInput($obj);
 					$obj.removeAttr('aria-disabled');
 					$('.multiselect-list', $obj).removeClass('disabled');
-					$('.multiselect-button > button', $wrapper).removeAttr('disabled');
+					$('.multiselect-button > button', $wrapper).prop('disabled', false);
 					$obj.append($input);
 					makeSuggsetionsBlock($obj);
 
@@ -202,6 +203,44 @@ jQuery(function($) {
 					ms.options.disabled = false;
 				}
 			});
+		},
+
+		/**
+		 * Modify one or more multiselect options after multiselect object has been created.
+		 *
+		 * @return jQuery
+		 */
+		modify: function(options) {
+			return this.each(function() {
+				var $obj = $(this),
+					ms = $(this).data('multiSelect');
+
+				for (var ms_key in ms.options) {
+					if (ms_key in options) {
+						ms.options[ms_key] = options[ms_key];
+					}
+
+					/*
+					 * When changing the option "addNew" few things need to happen:
+					 *   1) previous search results must be cleared, in case same search string is requested. So
+					 *      a new request is sent and new results are received. With or without "(new)".
+					 *   2) Already selected "(new)" items must be hidden and disabled, so that they are not sent
+					 *      when form is submitted.
+					 *   3) Already visible block with results must be hidden. It will reappear on new search.
+					 */
+					if (ms_key === 'addNew') {
+						cleanLastSearch($obj);
+
+						$('input[name*="[new]"]', $obj)
+							.prop('disabled', !ms.options[ms_key])
+							.each(function() {
+								$('.selected li[data-id="' + this.value + '"]', $obj).toggle(ms.options[ms_key]);
+							});
+
+						hideAvailable($obj);
+					}
+				}
+			});
 		}
 	};
 
@@ -227,7 +266,7 @@ jQuery(function($) {
 	 * @param string options['popup']['parameters']
 	 * @param int    options['popup']['width']
 	 * @param int    options['popup']['height']
-	 * @param string options['styles']				additional style for .multiselect-wrapper (optional)
+	 * @param string options['styles']				additional style for multiselect wrapper HTML element (optional)
 	 * @param string options['styles']['property']
 	 * @param string options['styles']['value']
 	 *
@@ -292,7 +331,7 @@ jQuery(function($) {
 
 			// add wrap
 			obj.wrap(jQuery('<div>', {
-				'class': 'multiselect-wrapper',
+				'class': ZBX_STYLE_CLASS,
 				css: options.styles
 			}));
 
@@ -343,7 +382,7 @@ jQuery(function($) {
 				});
 
 				if (options.disabled) {
-					popupButton.attr('disabled', true);
+					popupButton.prop('disabled', true);
 				}
 
 				popupButton.click(function(event) {
@@ -426,7 +465,7 @@ jQuery(function($) {
 							window.setTimeout(function() {
 								values.isWaiting = false;
 
-								var search = $input.val().replace(/^\s+/g, '');
+								var search = $input.val().replace(/^\s+|\s+$/g, '');
 
 								// re-check search after delay
 								if (search !== '' && $input.data('lastSearch') != search) {
@@ -442,7 +481,7 @@ jQuery(function($) {
 									var request_data = {
 										search: values.search,
 										limit: getLimit(values, options)
-									}
+									};
 
 									jqxhr = $.ajax({
 										url: options.url + '&curtime=' + new CDate().getTime(),
@@ -636,16 +675,18 @@ jQuery(function($) {
 		if (options.addNew) {
 			var value = values['search'].replace(/^\s+|\s+$/g, '');
 
-			if (!empty(value)) {
+			if (value.length) {
 				var addNew = false;
 
-				if (!empty(data) || objectLength(values.selected) > 0) {
-					// check if value exist in availables
-					if (!empty(data)) {
-						var names = {};
+				if (data.length || objectLength(values.selected) > 0) {
+					var names = {};
 
+					// check if value exists among available
+					if (data.length) {
 						$.each(data, function(i, item) {
-							names[item.name.toUpperCase()] = true;
+							if (item.name === value) {
+								names[item.name.toUpperCase()] = true;
+							}
 						});
 
 						if (typeof names[value.toUpperCase()] === 'undefined') {
@@ -653,10 +694,8 @@ jQuery(function($) {
 						}
 					}
 
-					// check if value exist in selected
+					// check if value exists among selected
 					if (!addNew && objectLength(values.selected) > 0) {
-						var names = {};
-
 						$.each(values.selected, function(i, item) {
 							if (typeof item.isNew === 'undefined') {
 								names[item.name.toUpperCase()] = true;
